@@ -387,6 +387,217 @@ def get_delivery_rejected_reason_dic():
         14: "Sin Stock Para Remaquilar"
     }
 
+def _get_schedule_rejected_comments(event_info):
+    if 'schedule_rejected_1_comments' in event_info and event_info['schedule_rejected_1_comments']:
+        return event_info['schedule_rejected_1_comments']
+    if 'schedule_rejected_2_comments' in event_info and event_info['schedule_rejected_2_comments']:
+        return event_info['schedule_rejected_2_comments']
+    if 'schedule_rejected_3_comments' in event_info and event_info['schedule_rejected_3_comments']:
+        return event_info['schedule_rejected_3_comments']
+    return None
+
+def get_status_info(delivery_order):
+    events_info = None
+    status = None
+    description = None
+    last_event_timestamp = None
+
+    if delivery_order['status'] == DeliveryOrderStatusType.Planning.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.VirtuallyReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Planificación'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.PhysicallyReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Recepción Física'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2BReceptionRejected.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Rechazada B2B'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DistributionCenterReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.SERTravelling.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Viajando SER'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.SERReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryCourierReceived.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryConfirmed.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Entrega Agendada'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryNotConfirmed.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Entrega Agendada'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryScheduled.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2CTraveling.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'En Ruta'
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.NotDelivered.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+
+    elif DeliveryOrderStatusType.Delivered.value in delivery_order['statuses']:
+        events_info = filter(
+            lambda x: x['status'] == DeliveryOrderStatusType.Delivered.value,
+            delivery_order['events_info']
+        )
+        status = 'Entregado'
+        description = 'Entrega realizada'
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryRejected.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status = 'Entrega Rechazada'
+        description = _get_schedule_rejected_comments(events_info[len(events_info) - 1]['info']) if \
+            _get_schedule_rejected_comments(events_info[len(events_info) - 1]['info']) is not None \
+            else "Entrega Rechazada"
+
+    elif delivery_order['status'] in DELIVERY_ORDER_REJECTED_STATUSES:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description = get_rejected_reason(events_info[len(events_info) - 1]['info'])
+        if description is None:
+            description = "Entrega Rechazada"
+
+    elif delivery_order['status'] == DeliveryOrderStatusType.NotDeliverable.value:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']]
+    else:
+        events_info = filter(
+            lambda x: x['status'] == delivery_order['status'],
+            delivery_order['events_info']
+        )
+
+        status_dic = get_delivery_order_status_dic()
+        status = status_dic[delivery_order['status']]
+
+        description_dic = get_delivery_order_status_description_dic()
+        description = description_dic[delivery_order['status']] \
+            if delivery_order['status'] in description_dic \
+                else status
+
+
+    if events_info:
+        last_event_timestamp = events_info[len(events_info) - 1]['timestamp'].split('.')[0]
+
+    return status, description, last_event_timestamp
+
 def get_macro_status(delivery_order):
     in_route_amount = len(filter(lambda x: x == 17, delivery_order['statuses']))
     status = get_delivery_order_status_dic()
